function [uNew, yNew, uconst, yconst] = signalsNormalization(u, y)
%
% [uNew, yNew, uconst, yconst] = signalsNormalization(u, y)
%
% Utility function to normalize the signals (useful when units or actual
% signal values span different orders of magnitude)
%
% ----------------------------------------------
% Authors: Tommaso Bradde, Stefano Grivet-Talocia
% EMC group, Politecnico di Torino, Italy
% March 2023
%-----------------------------------------------


% Remove first point (see https://doi.org/10.3390/en14092471)
uNew = u-u(1);
yNew = y-y(1);
nSamples = length(uNew);

% Compute normalization constants (may be changed if required)
uconst = norm(uNew)/sqrt(nSamples);
yconst = norm(yNew)/sqrt(nSamples);

% Normalize signals
uNew = uNew./uconst;
yNew = yNew./yconst;

return
end
